@@ -9,6 +9,13 @@ class Response(ResponseBase):
 
         super(Response, self).__init__(content, *args, **kargs)
 
+    @classmethod
+    def force_type(cls, response, environ=None):
+        if isinstance(response, (list, dict)):
+            return cls(response)
+        else:
+            return super(Response, cls).force_type(response, environ)
+
 def to_json(content):
     indent = None
     if current_app.config['JSONIFY_PRETTYPRINT_REGULAR'] and not request.is_xhr:
